# HumanCVer

# 安装步骤
1. 编辑代码
2. 删除build文件夹
3. python setup.py install 
4. pip install .

## 历程
* 2022.05.29 human-cver-0.1.0
* 2022.05.20 human-cver-0.1.1

## 2022.06.04: 0.1.3
* [x] 添加 __version__
* [x] 自动生成 conda environments.yaml
* [x] 支持多级configs文件夹
* [x] 支持模型类不需要参数
* [x] convert_ckpt_to_pth（去掉头部model.）